@@ -45,6 +45,8 @@ def correlate(x, y):
     tf.Tensor:
         the result of conj(x)*y
     """
+    x = tf.cast(x, tf.complex64)
+    y = tf.cast(y, tf.complex64)
     return tf.math.conj(x) * y
 
 
